@@ -5,7 +5,7 @@ use crate::components::{Arsc, Config, Header, Package, ResourceType, Specs, Stri
 /// It handles the header generation with predefined information
 pub(in crate::writer) trait WithHeader: ByteSizing {
     /// The `header_size` attribute in generated header object
-    const HEADER_SIZE: u16;
+    fn get_header_size(&self) -> u16;
     /// The `resource_type` attribute in generated header object
     const RESOURCE_TYPE: ResourceType;
 
@@ -13,33 +13,44 @@ pub(in crate::writer) trait WithHeader: ByteSizing {
     fn header(&self) -> Header {
         Header {
             resource_type: Self::RESOURCE_TYPE,
-            header_size: Self::HEADER_SIZE,
+            header_size: self.get_header_size(),
             size: self.size() as u64,
         }
     }
 }
 
 impl WithHeader for Arsc {
-    const HEADER_SIZE: u16 = 0x000C;
+    fn get_header_size(&self) -> u16 {
+        0x000C
+    }
     const RESOURCE_TYPE: ResourceType = ResourceType::Table;
 }
 
 impl WithHeader for StringPool {
-    const HEADER_SIZE: u16 = 0x001C;
+    fn get_header_size(&self) -> u16 {
+        0x001C
+    }
     const RESOURCE_TYPE: ResourceType = ResourceType::StringPool;
 }
 
 impl WithHeader for Package {
-    const HEADER_SIZE: u16 = 0x0120;
+    fn get_header_size(&self) -> u16 {
+        0x0120
+    }
     const RESOURCE_TYPE: ResourceType = ResourceType::TablePackage;
 }
 
 impl WithHeader for Specs {
-    const HEADER_SIZE: u16 = 0x0010;
+    fn get_header_size(&self) -> u16 {
+        self.header_size
+    }
     const RESOURCE_TYPE: ResourceType = ResourceType::TableTypeSpec;
 }
 
 impl WithHeader for Config {
-    const HEADER_SIZE: u16 = 0x0054;
+    fn get_header_size(&self) -> u16 {
+        self.header_size
+    }
+
     const RESOURCE_TYPE: ResourceType = ResourceType::TableType;
 }
